@@ -1,5 +1,5 @@
 package Spek;
-our $VERSION = '0.0.6';
+our $VERSION = '0.0.7';
 1;
 
 __END__
@@ -28,9 +28,9 @@ cpanm Spek
 =head1 USAGE
 
 
-=head2 create http endpoints
+=head2 declare http endpoints
 
-Http routes should be defined at swat test files format:
+To declare http endpoint you should write swat tests:
 
 
 =head3 GET /users
@@ -63,7 +63,9 @@ Follow L<swat|https://github.com/melezhik/swat> for full explanation of swat tes
 
     $ spek
     
-    ... you should see HTTP::Server::PSGI: Accepting connections at http://0:5000/
+    ... you should see:
+    
+    HTTP::Server::PSGI: Accepting connections at http://0:5000/
 
 
 =head2 run swat tests
@@ -75,7 +77,11 @@ Follow L<swat|https://github.com/melezhik/swat> for full explanation of swat tes
     $ swat
     
     ... you should get an errors like <HTTP/1.0 404 Not Found>
-    ... as you have to implement endpoints
+    ... as endpoints are not *defined* yet
+    
+    127.0.0.1 - - [16/Mar/2016:09:00:03 +0300] "GET /users HTTP/1.1" 404 20 "-" "curl/7.47.0-DEV"
+    127.0.0.1 - - [16/Mar/2016:09:00:03 +0300] "GET /user/foo HTTP/1.1" 404 20 "-" "curl/7.47.0-DEV"
+    127.0.0.1 - - [16/Mar/2016:09:00:03 +0300] "POST /user HTTP/1.1" 404 20 "-" "curl/7.47.0-DEV"
 
 
 =head2 implement endpoints
@@ -229,9 +235,11 @@ user/post.pm
 
 =head2 Run tests
 
+Now you have a specifi(K)ation simply just running:
+
     $ swat
     
-    ... should see :
+    ... should see:
     
     /home/vagrant/.swat/.cache/5738/prove/crud/META/request.t ..
     # @META
@@ -253,6 +261,25 @@ user/post.pm
     Result: PASS
 
 
+=head1 appliaction introspection
+
+
+=head2 routes
+
+To inspect all available routes:
+
+    $ spek --routes
+
+
+=head2 meta stories
+
+To inspect meta stories:
+
+    $ find ./ -name meta.txt -exec tail -v {} \;
+
+Read L<swat|https://github.com/melezhik/swat#meta-stories> documentation to know more about swat meta stories.
+
+
 =head1 Author
 
 L<Alexey Melezhik|maito:melezhik@gmail.com>
